@@ -1,10 +1,10 @@
 from cms import signals
 from cms.models import Page
-from djangocms_algolia.index import AlgoliaPageDataProxy
+from djangocms_algolia.index import TitleProxy
 
 
 def update_page_index(sender, instance: Page, language: str, **kwargs) -> None:
-    obj: AlgoliaPageDataProxy = AlgoliaPageDataProxy.objects.get(page=instance, language=language)
+    obj: TitleProxy = TitleProxy.objects.get(page=instance, language=language)
     obj.save()
 
 
